summaryrefslogtreecommitdiff
path: root/include/salhelper
diff options
context:
space:
mode:
authorJesús Corrius <jcorrius@gmail.com>2013-09-26 10:21:12 +0200
committerJesús Corrius <jcorrius@gmail.com>2013-09-26 10:21:12 +0200
commit6a3cf741d1d4d9e700c14da6d6ae386d3aa372f8 (patch)
tree31e7dd398ac2fdac83324154c988f9f304e6ab75 /include/salhelper
parenta1bc57563f659579e889f279d7f63a9fb487dcb2 (diff)
Otherwhise -> Otherwise
Change-Id: Iaec23e1d240f675a04b52cd251c4cb2a1242bb44
Diffstat (limited to 'include/salhelper')
-rw-r--r--include/salhelper/singletonref.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/salhelper/singletonref.hxx b/include/salhelper/singletonref.hxx
index a602e50cc4bf..af4327c985b9 100644
--- a/include/salhelper/singletonref.hxx
+++ b/include/salhelper/singletonref.hxx
@@ -85,7 +85,7 @@ class SingletonRef
/** @short standard ctor.
The internal wrapped object is created only,
- if its ref count was 0. Otherwhise this method
+ if its ref count was 0. Otherwise this method
does nothing ... except increasing of the internal
ref count!
*/
@@ -95,7 +95,7 @@ class SingletonRef
::osl::MutexGuard aLock(SingletonRef::ownStaticLock());
// must be increased before(!) the check is done.
- // Otherwhise this check can fail inside the same thread ...
+ // Otherwise this check can fail inside the same thread ...
++m_nRef;
if (m_nRef == 1)
m_pInstance = new SingletonClass();
@@ -109,7 +109,7 @@ class SingletonRef
/** @short standard dtor.
The internal wrapped object is removed only,
- if its ref count wil be 0. Otherwhise this method
+ if its ref count wil be 0. Otherwise this method
does nothing ... except decreasing of the internal
ref count!
*/
@@ -119,7 +119,7 @@ class SingletonRef
::osl::MutexGuard aLock(SingletonRef::ownStaticLock());
// must be decreased before(!) the check is done.
- // Otherwhise this check can fail inside the same thread ...
+ // Otherwise this check can fail inside the same thread ...
--m_nRef;
if (m_nRef == 0)
{